@@ -48,9 +48,25 @@ require_once ABSPATH . WPINC . '/class-walker-nav-menu.php';
 function wp_nav_menu( $args = array() ) {
 	static $menu_id_slugs = array();
 
-	$defaults = array( 'menu' => '', 'container' => 'div', 'container_class' => '', 'container_id' => '', 'menu_class' => 'menu', 'menu_id' => '',
-	'echo' => true, 'fallback_cb' => 'wp_page_menu', 'before' => '', 'after' => '', 'link_before' => '', 'link_after' => '', 'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s</ul>', 'item_spacing' => 'preserve',
-	'depth' => 0, 'walker' => '', 'theme_location' => '' );
+	$defaults = array(
+		'menu'            => '',
+		'container'       => 'div',
+		'container_class' => '',
+		'container_id'    => '',
+		'menu_class'      => 'menu',
+		'menu_id'         => '',
+		'echo'            => true,
+		'fallback_cb'     => 'wp_page_menu',
+		'before'          => '',
+		'after'           => '',
+		'link_before'     => '',
+		'link_after'      => '',
+		'items_wrap'      => '<ul id="%1$s" class="%2$s">%3$s</ul>',
+		'item_spacing'    => 'preserve',
+		'depth'           => 0,
+		'walker'          => '',
+		'theme_location'  => '',
+	);
 
 	$args = wp_parse_args( $args, $defaults );
 
@@ -100,11 +116,12 @@ function wp_nav_menu( $args = array() ) {
 	$menu = wp_get_nav_menu_object( $args->menu );
 
 	// Get the nav menu based on the theme_location
-	if ( ! $menu && $args->theme_location && ( $locations = get_nav_menu_locations() ) && isset( $locations[ $args->theme_location ] ) )
+	if ( ! $menu && $args->theme_location && ( $locations = get_nav_menu_locations() ) && isset( $locations[ $args->theme_location ] ) ) {
 		$menu = wp_get_nav_menu_object( $locations[ $args->theme_location ] );
+	}
 
 	// get the first menu that has items if we still can't find a menu
-	if ( ! $menu && !$args->theme_location ) {
+	if ( ! $menu && ! $args->theme_location ) {
 		$menus = wp_get_nav_menus();
 		foreach ( $menus as $menu_maybe ) {
 			if ( $menu_items = wp_get_nav_menu_items( $menu_maybe->term_id, array( 'update_post_term_cache' => false ) ) ) {
@@ -119,8 +136,9 @@ function wp_nav_menu( $args = array() ) {
 	}
 
 	// If the menu exists, get its items.
-	if ( $menu && ! is_wp_error($menu) && !isset($menu_items) )
+	if ( $menu && ! is_wp_error( $menu ) && ! isset( $menu_items ) ) {
 		$menu_items = wp_get_nav_menu_items( $menu->term_id, array( 'update_post_term_cache' => false ) );
+	}
 
 	/*
 	 * If no menu was found:
@@ -130,12 +148,14 @@ function wp_nav_menu( $args = array() ) {
 	 *  - Fall back, but only if no theme location was specified.
 	 *  - Otherwise, bail.
 	 */
-	if ( ( !$menu || is_wp_error($menu) || ( isset($menu_items) && empty($menu_items) && !$args->theme_location ) )
-		&& isset( $args->fallback_cb ) && $args->fallback_cb && is_callable( $args->fallback_cb ) )
+	if ( ( ! $menu || is_wp_error( $menu ) || ( isset( $menu_items ) && empty( $menu_items ) && ! $args->theme_location ) )
+		&& isset( $args->fallback_cb ) && $args->fallback_cb && is_callable( $args->fallback_cb ) ) {
 			return call_user_func( $args->fallback_cb, (array) $args );
+	}
 
-	if ( ! $menu || is_wp_error( $menu ) )
+	if ( ! $menu || is_wp_error( $menu ) ) {
 		return false;
+	}
 
 	$nav_menu = $items = '';
 
@@ -152,9 +172,9 @@ function wp_nav_menu( $args = array() ) {
 		$allowed_tags = apply_filters( 'wp_nav_menu_container_allowedtags', array( 'div', 'nav' ) );
 		if ( is_string( $args->container ) && in_array( $args->container, $allowed_tags ) ) {
 			$show_container = true;
-			$class = $args->container_class ? ' class="' . esc_attr( $args->container_class ) . '"' : ' class="menu-'. $menu->slug .'-container"';
-			$id = $args->container_id ? ' id="' . esc_attr( $args->container_id ) . '"' : '';
-			$nav_menu .= '<'. $args->container . $id . $class . '>';
+			$class          = $args->container_class ? ' class="' . esc_attr( $args->container_class ) . '"' : ' class="menu-' . $menu->slug . '-container"';
+			$id             = $args->container_id ? ' id="' . esc_attr( $args->container_id ) . '"' : '';
+			$nav_menu      .= '<' . $args->container . $id . $class . '>';
 		}
 	}
 
@@ -164,15 +184,17 @@ function wp_nav_menu( $args = array() ) {
 	$sorted_menu_items = $menu_items_with_children = array();
 	foreach ( (array) $menu_items as $menu_item ) {
 		$sorted_menu_items[ $menu_item->menu_order ] = $menu_item;
-		if ( $menu_item->menu_item_parent )
+		if ( $menu_item->menu_item_parent ) {
 			$menu_items_with_children[ $menu_item->menu_item_parent ] = true;
+		}
 	}
 
 	// Add the menu-item-has-children class where applicable
 	if ( $menu_items_with_children ) {
 		foreach ( $sorted_menu_items as &$menu_item ) {
-			if ( isset( $menu_items_with_children[ $menu_item->ID ] ) )
+			if ( isset( $menu_items_with_children[ $menu_item->ID ] ) ) {
 				$menu_item->classes[] = 'menu-item-has-children';
+			}
 		}
 	}
 
@@ -189,7 +211,7 @@ function wp_nav_menu( $args = array() ) {
 	$sorted_menu_items = apply_filters( 'wp_nav_menu_objects', $sorted_menu_items, $args );
 
 	$items .= walk_nav_menu_tree( $sorted_menu_items, $args->depth, $args );
-	unset($sorted_menu_items);
+	unset( $sorted_menu_items );
 
 	// Attributes
 	if ( ! empty( $args->menu_id ) ) {
@@ -197,10 +219,11 @@ function wp_nav_menu( $args = array() ) {
 	} else {
 		$wrap_id = 'menu-' . $menu->slug;
 		while ( in_array( $wrap_id, $menu_id_slugs ) ) {
-			if ( preg_match( '#-(\d+)$#', $wrap_id, $matches ) )
-				$wrap_id = preg_replace('#-(\d+)$#', '-' . ++$matches[1], $wrap_id );
-			else
+			if ( preg_match( '#-(\d+)$#', $wrap_id, $matches ) ) {
+				$wrap_id = preg_replace( '#-(\d+)$#', '-' . ++$matches[1], $wrap_id );
+			} else {
 				$wrap_id = $wrap_id . '-1';
+			}
 		}
 	}
 	$menu_id_slugs[] = $wrap_id;
@@ -231,14 +254,16 @@ function wp_nav_menu( $args = array() ) {
 	$items = apply_filters( "wp_nav_menu_{$menu->slug}_items", $items, $args );
 
 	// Don't print any markup if there are no items at this point.
-	if ( empty( $items ) )
+	if ( empty( $items ) ) {
 		return false;
+	}
 
 	$nav_menu .= sprintf( $args->items_wrap, esc_attr( $wrap_id ), esc_attr( $wrap_class ), $items );
 	unset( $items );
 
-	if ( $show_container )
+	if ( $show_container ) {
 		$nav_menu .= '</' . $args->container . '>';
+	}
 
 	/**
 	 * Filters the HTML content for navigation menus.
@@ -252,10 +277,11 @@ function wp_nav_menu( $args = array() ) {
 	 */
 	$nav_menu = apply_filters( 'wp_nav_menu', $nav_menu, $args );
 
-	if ( $args->echo )
+	if ( $args->echo ) {
 		echo $nav_menu;
-	else
+	} else {
 		return $nav_menu;
+	}
 }
 
 /**
@@ -272,28 +298,29 @@ function wp_nav_menu( $args = array() ) {
 function _wp_menu_item_classes_by_context( &$menu_items ) {
 	global $wp_query, $wp_rewrite;
 
-	$queried_object = $wp_query->get_queried_object();
+	$queried_object    = $wp_query->get_queried_object();
 	$queried_object_id = (int) $wp_query->queried_object_id;
 
-	$active_object = '';
-	$active_ancestor_item_ids = array();
-	$active_parent_item_ids = array();
-	$active_parent_object_ids = array();
+	$active_object               = '';
+	$active_ancestor_item_ids    = array();
+	$active_parent_item_ids      = array();
+	$active_parent_object_ids    = array();
 	$possible_taxonomy_ancestors = array();
-	$possible_object_parents = array();
-	$home_page_id = (int) get_option( 'page_for_posts' );
+	$possible_object_parents     = array();
+	$home_page_id                = (int) get_option( 'page_for_posts' );
 
 	if ( $wp_query->is_singular && ! empty( $queried_object->post_type ) && ! is_post_type_hierarchical( $queried_object->post_type ) ) {
 		foreach ( (array) get_object_taxonomies( $queried_object->post_type ) as $taxonomy ) {
 			if ( is_taxonomy_hierarchical( $taxonomy ) ) {
 				$term_hierarchy = _get_term_hierarchy( $taxonomy );
-				$terms = wp_get_object_terms( $queried_object_id, $taxonomy, array( 'fields' => 'ids' ) );
+				$terms          = wp_get_object_terms( $queried_object_id, $taxonomy, array( 'fields' => 'ids' ) );
 				if ( is_array( $terms ) ) {
 					$possible_object_parents = array_merge( $possible_object_parents, $terms );
-					$term_to_ancestor = array();
+					$term_to_ancestor        = array();
 					foreach ( (array) $term_hierarchy as $anc => $descs ) {
-						foreach ( (array) $descs as $desc )
+						foreach ( (array) $descs as $desc ) {
 							$term_to_ancestor[ $desc ] = $anc;
+						}
 					}
 
 					foreach ( $terms as $desc ) {
@@ -312,11 +339,12 @@ function _wp_menu_item_classes_by_context( &$menu_items ) {
 			}
 		}
 	} elseif ( ! empty( $queried_object->taxonomy ) && is_taxonomy_hierarchical( $queried_object->taxonomy ) ) {
-		$term_hierarchy = _get_term_hierarchy( $queried_object->taxonomy );
+		$term_hierarchy   = _get_term_hierarchy( $queried_object->taxonomy );
 		$term_to_ancestor = array();
 		foreach ( (array) $term_hierarchy as $anc => $descs ) {
-			foreach ( (array) $descs as $desc )
+			foreach ( (array) $descs as $desc ) {
 				$term_to_ancestor[ $desc ] = $anc;
+			}
 		}
 		$desc = $queried_object->term_id;
 		do {
@@ -333,14 +361,15 @@ function _wp_menu_item_classes_by_context( &$menu_items ) {
 
 	$possible_object_parents = array_filter( $possible_object_parents );
 
-	$front_page_url = home_url();
-	$front_page_id  = (int) get_option( 'page_on_front' );
+	$front_page_url         = home_url();
+	$front_page_id          = (int) get_option( 'page_on_front' );
+	$privacy_policy_page_id = (int) get_option( 'wp_page_for_privacy_policy' );
 
 	foreach ( (array) $menu_items as $key => $menu_item ) {
 
-		$menu_items[$key]->current = false;
+		$menu_items[ $key ]->current = false;
 
-		$classes = (array) $menu_item->classes;
+		$classes   = (array) $menu_item->classes;
 		$classes[] = 'menu-item';
 		$classes[] = 'menu-item-type-' . $menu_item->type;
 		$classes[] = 'menu-item-object-' . $menu_item->object;
@@ -350,13 +379,18 @@ function _wp_menu_item_classes_by_context( &$menu_items ) {
 			$classes[] = 'menu-item-home';
 		}
 
+		// This menu item is set as the 'Privacy Policy Page'.
+		if ( 'post_type' === $menu_item->type && $privacy_policy_page_id === (int) $menu_item->object_id ) {
+			$classes[] = 'menu-item-privacy-policy';
+		}
+
 		// if the menu item corresponds to a taxonomy term for the currently-queried non-hierarchical post object
 		if ( $wp_query->is_singular && 'taxonomy' == $menu_item->type && in_array( $menu_item->object_id, $possible_object_parents ) ) {
 			$active_parent_object_ids[] = (int) $menu_item->object_id;
-			$active_parent_item_ids[] = (int) $menu_item->db_id;
-			$active_object = $queried_object->post_type;
+			$active_parent_item_ids[]   = (int) $menu_item->db_id;
+			$active_object              = $queried_object->post_type;
 
-		// if the menu item corresponds to the currently-queried post or taxonomy object
+			// if the menu item corresponds to the currently-queried post or taxonomy object
 		} elseif (
 			$menu_item->object_id == $queried_object_id &&
 			(
@@ -365,11 +399,11 @@ function _wp_menu_item_classes_by_context( &$menu_items ) {
 				( 'taxonomy' == $menu_item->type && ( $wp_query->is_category || $wp_query->is_tag || $wp_query->is_tax ) && $queried_object->taxonomy == $menu_item->object )
 			)
 		) {
-			$classes[] = 'current-menu-item';
-			$menu_items[$key]->current = true;
-			$_anc_id = (int) $menu_item->db_id;
+			$classes[]                   = 'current-menu-item';
+			$menu_items[ $key ]->current = true;
+			$_anc_id                     = (int) $menu_item->db_id;
 
-			while(
+			while (
 				( $_anc_id = get_post_meta( $_anc_id, '_menu_item_menu_item_parent', true ) ) &&
 				! in_array( $_anc_id, $active_ancestor_item_ids )
 			) {
@@ -383,20 +417,20 @@ function _wp_menu_item_classes_by_context( &$menu_items ) {
 				$classes[] = 'current_page_item';
 			}
 
-			$active_parent_item_ids[] = (int) $menu_item->menu_item_parent;
+			$active_parent_item_ids[]   = (int) $menu_item->menu_item_parent;
 			$active_parent_object_ids[] = (int) $menu_item->post_parent;
-			$active_object = $menu_item->object;
+			$active_object              = $menu_item->object;
 
-		// if the menu item corresponds to the currently-queried post type archive
+			// if the menu item corresponds to the currently-queried post type archive
 		} elseif (
 			'post_type_archive' == $menu_item->type &&
 			is_post_type_archive( array( $menu_item->object ) )
 		) {
-			$classes[] = 'current-menu-item';
-			$menu_items[$key]->current = true;
-			$_anc_id = (int) $menu_item->db_id;
+			$classes[]                   = 'current-menu-item';
+			$menu_items[ $key ]->current = true;
+			$_anc_id                     = (int) $menu_item->db_id;
 
-			while(
+			while (
 				( $_anc_id = get_post_meta( $_anc_id, '_menu_item_menu_item_parent', true ) ) &&
 				! in_array( $_anc_id, $active_ancestor_item_ids )
 			) {
@@ -405,7 +439,7 @@ function _wp_menu_item_classes_by_context( &$menu_items ) {
 
 			$active_parent_item_ids[] = (int) $menu_item->menu_item_parent;
 
-		// if the menu item corresponds to the currently-requested URL
+			// if the menu item corresponds to the currently-requested URL
 		} elseif ( 'custom' == $menu_item->object && isset( $_SERVER['HTTP_HOST'] ) ) {
 			$_root_relative_current = untrailingslashit( $_SERVER['REQUEST_URI'] );
 
@@ -413,17 +447,27 @@ function _wp_menu_item_classes_by_context( &$menu_items ) {
 			if ( is_customize_preview() ) {
 				$_root_relative_current = strtok( untrailingslashit( $_SERVER['REQUEST_URI'] ), '?' );
 			}
-			$current_url = set_url_scheme( 'http://' . $_SERVER['HTTP_HOST'] . $_root_relative_current );
-			$raw_item_url = strpos( $menu_item->url, '#' ) ? substr( $menu_item->url, 0, strpos( $menu_item->url, '#' ) ) : $menu_item->url;
-			$item_url = set_url_scheme( untrailingslashit( $raw_item_url ) );
+
+			$current_url        = set_url_scheme( 'http://' . $_SERVER['HTTP_HOST'] . $_root_relative_current );
+			$raw_item_url       = strpos( $menu_item->url, '#' ) ? substr( $menu_item->url, 0, strpos( $menu_item->url, '#' ) ) : $menu_item->url;
+			$item_url           = set_url_scheme( untrailingslashit( $raw_item_url ) );
 			$_indexless_current = untrailingslashit( preg_replace( '/' . preg_quote( $wp_rewrite->index, '/' ) . '$/', '', $current_url ) );
 
-			if ( $raw_item_url && in_array( $item_url, array( $current_url, $_indexless_current, $_root_relative_current ) ) ) {
-				$classes[] = 'current-menu-item';
-				$menu_items[$key]->current = true;
-				$_anc_id = (int) $menu_item->db_id;
+			$matches = array(
+				$current_url,
+				urldecode( $current_url ),
+				$_indexless_current,
+				urldecode( $_indexless_current ),
+				$_root_relative_current,
+				urldecode( $_root_relative_current ),
+			);
 
-				while(
+			if ( $raw_item_url && in_array( $item_url, $matches ) ) {
+				$classes[]                   = 'current-menu-item';
+				$menu_items[ $key ]->current = true;
+				$_anc_id                     = (int) $menu_item->db_id;
+
+				while (
 					( $_anc_id = get_post_meta( $_anc_id, '_menu_item_menu_item_parent', true ) ) &&
 					! in_array( $_anc_id, $active_ancestor_item_ids )
 				) {
@@ -434,34 +478,36 @@ function _wp_menu_item_classes_by_context( &$menu_items ) {
 					// Back compat for home link to match wp_page_menu()
 					$classes[] = 'current_page_item';
 				}
-				$active_parent_item_ids[] = (int) $menu_item->menu_item_parent;
+				$active_parent_item_ids[]   = (int) $menu_item->menu_item_parent;
 				$active_parent_object_ids[] = (int) $menu_item->post_parent;
-				$active_object = $menu_item->object;
+				$active_object              = $menu_item->object;
 
-			// give front page item current-menu-item class when extra query arguments involved
+				// give front page item current-menu-item class when extra query arguments involved
 			} elseif ( $item_url == $front_page_url && is_front_page() ) {
 				$classes[] = 'current-menu-item';
 			}
 
-			if ( untrailingslashit($item_url) == home_url() )
+			if ( untrailingslashit( $item_url ) == home_url() ) {
 				$classes[] = 'menu-item-home';
+			}
 		}
 
 		// back-compat with wp_page_menu: add "current_page_parent" to static home page link for any non-page query
-		if ( ! empty( $home_page_id ) && 'post_type' == $menu_item->type && empty( $wp_query->is_page ) && $home_page_id == $menu_item->object_id )
+		if ( ! empty( $home_page_id ) && 'post_type' == $menu_item->type && empty( $wp_query->is_page ) && $home_page_id == $menu_item->object_id ) {
 			$classes[] = 'current_page_parent';
+		}
 
-		$menu_items[$key]->classes = array_unique( $classes );
+		$menu_items[ $key ]->classes = array_unique( $classes );
 	}
 	$active_ancestor_item_ids = array_filter( array_unique( $active_ancestor_item_ids ) );
-	$active_parent_item_ids = array_filter( array_unique( $active_parent_item_ids ) );
+	$active_parent_item_ids   = array_filter( array_unique( $active_parent_item_ids ) );
 	$active_parent_object_ids = array_filter( array_unique( $active_parent_object_ids ) );
 
 	// set parent's class
 	foreach ( (array) $menu_items as $key => $parent_item ) {
-		$classes = (array) $parent_item->classes;
-		$menu_items[$key]->current_item_ancestor = false;
-		$menu_items[$key]->current_item_parent = false;
+		$classes                                   = (array) $parent_item->classes;
+		$menu_items[ $key ]->current_item_ancestor = false;
+		$menu_items[ $key ]->current_item_parent   = false;
 
 		if (
 			isset( $parent_item->type ) &&
@@ -490,26 +536,29 @@ function _wp_menu_item_classes_by_context( &$menu_items ) {
 			$classes[] = empty( $queried_object->taxonomy ) ? 'current-' . $queried_object->post_type . '-ancestor' : 'current-' . $queried_object->taxonomy . '-ancestor';
 		}
 
-		if ( in_array(  intval( $parent_item->db_id ), $active_ancestor_item_ids ) ) {
-			$classes[] = 'current-menu-ancestor';
-			$menu_items[$key]->current_item_ancestor = true;
+		if ( in_array( intval( $parent_item->db_id ), $active_ancestor_item_ids ) ) {
+			$classes[]                                 = 'current-menu-ancestor';
+			$menu_items[ $key ]->current_item_ancestor = true;
 		}
 		if ( in_array( $parent_item->db_id, $active_parent_item_ids ) ) {
-			$classes[] = 'current-menu-parent';
-			$menu_items[$key]->current_item_parent = true;
+			$classes[]                               = 'current-menu-parent';
+			$menu_items[ $key ]->current_item_parent = true;
 		}
-		if ( in_array( $parent_item->object_id, $active_parent_object_ids ) )
+		if ( in_array( $parent_item->object_id, $active_parent_object_ids ) ) {
 			$classes[] = 'current-' . $active_object . '-parent';
+		}
 
 		if ( 'post_type' == $parent_item->type && 'page' == $parent_item->object ) {
 			// Back compat classes for pages to match wp_page_menu()
-			if ( in_array('current-menu-parent', $classes) )
+			if ( in_array( 'current-menu-parent', $classes ) ) {
 				$classes[] = 'current_page_parent';
-			if ( in_array('current-menu-ancestor', $classes) )
+			}
+			if ( in_array( 'current-menu-ancestor', $classes ) ) {
 				$classes[] = 'current_page_ancestor';
+			}
 		}
 
-		$menu_items[$key]->classes = array_unique( $classes );
+		$menu_items[ $key ]->classes = array_unique( $classes );
 	}
 }
 
@@ -525,8 +574,8 @@ function _wp_menu_item_classes_by_context( &$menu_items ) {
  * @return string The HTML list content for the menu items.
  */
 function walk_nav_menu_tree( $items, $depth, $r ) {
-	$walker = ( empty($r->walker) ) ? new Walker_Nav_Menu : $r->walker;
-	$args = array( $items, $depth, $r );
+	$walker = ( empty( $r->walker ) ) ? new Walker_Nav_Menu : $r->walker;
+	$args   = array( $items, $depth, $r );
 
 	return call_user_func_array( array( $walker, 'walk' ), $args );
 }
